==> dde-daemon_5.13.12.orig.tar.xz: dde-daemon-5.13.12/misc/ts/com.deepin.daemon.Fprintd.policy/policy_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Pro přidání hesla zastupovaného otiskem prstu je požadováno ověření se</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Přidat heslo zastupované otiskem prstu</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Pro smazání hesel zastupovaných otiskem prstu je požadováno ověření se</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Smazat hesla zastupovaná otiskem prstu</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Pro přejmenování hesla, zastupovaného otiskem prstu, je požadováno ověření se</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Přejmenovat heslo zastupované otiskem prstu</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Pro provedení této akce je zapotřebí zadat heslo</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Spravovat hesla zastupovaná otiskem prstu</translation>
		</message>
	</context>
</TS>

==> dde-daemon_5.14.104.orig.tar.xz: dde-daemon-5.14.104/misc/ts/com.deepin.daemon.Fprintd.policy/policy_cs.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="cs" version="2.1">
	<context>
		<name>policy</name>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!message" line="0"/>
			<source>Authentication is required to add fingerprint password</source>
			<translation>Pro přidání hesla, zastupovaného otiskem prstu, je požadováno ověření se</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.enroll!description" line="0"/>
			<source>Add fingerprint password</source>
			<translation>Přidat heslo otiskem prstu</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!message" line="0"/>
			<source>Authentication is required to clear fingerprint passwords</source>
			<translation>Pro smazání hesel, zastupovaných otiskem prstu, je požadováno ověření se</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.delete-enrolled-fingers!description" line="0"/>
			<source>Clear fingerprint passwords</source>
			<translation>Smazat hesla otiskem prstu</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!message" line="0"/>
			<source>Authentication is required to rename fingerprint password</source>
			<translation>Pro přejmenování hesla, zastupovaného otiskem prstu, je požadováno ověření se</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.rename-enrolled-finger!description" line="0"/>
			<source>Rename fingerprint password</source>
			<translation>Přejmenovat heslo zastupované otiskem prstu</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!message" line="0"/>
			<source>Password is required to perform this action</source>
			<translation>Pro provedení této akce je zapotřebí zadat heslo</translation>
		</message>
		<message>
			<location filename="com.deepin.daemon.fprintd.manager!description" line="0"/>
			<source>Manage fingerprint passwords</source>
			<translation>Spravovat hesla zastupovaná otiskem prstu</translation>
		</message>
	</context>
</TS>
